'-------------------------------------------------------------------
'  clsFormSettings   VB2005
'  Klasse zum Speichern Form.Location, .Size, .Maximized
'  ber die Projekt.Settings
'  ebenso ColumnsWidth und DiplayIndex von Listview und DataGridView
'
'  Autor       peter.k.sauer@web.de
'  Created     14.03.2008
'  Update      23.10.2008
'-------------------------------------------------------------------



''' <summary>
''' Funktionen zum Speichern und Restore von FormSize, -Location und Windowstate(Maximize)
''' </summary>
''' <remarks></remarks>
Public Class clsFormSettings

   Public Sub New()
   End Sub

   ''' <summary>
   ''' Form auf Basis gespeicherter Daten ber Size und Location einstellen
   ''' </summary>
   ''' <param name="Frm">die Form</param>
   ''' <param name="Settings">Daten (String) aus den Einstellungen (Settings)</param>
   ''' <remarks></remarks>
   Public Sub FormRestore(ByVal Frm As Form, ByVal Settings As String)

      'beim 1. Mal sind noch keine Settings vorhanden
      If String.IsNullOrEmpty(Settings) Then
         Exit Sub
      End If

      Dim s() As String = Settings.Split(","c)
      Dim Size As New Size(Integer.Parse(s(3)), Integer.Parse(s(4)))
      Dim Pt As New Point(Integer.Parse(s(1)), Integer.Parse(s(2)))
      Dim Rect As Rectangle = My.Computer.Screen.WorkingArea

      'Maximalwerte beachten
      If Size.Width > Rect.Width Then
         Size.Width = Rect.Width
      End If
      If Size.Height > Rect.Height Then
         Size.Height = Rect.Height
      End If

      If Pt.Y < 0 Then
         Pt.Y = 0
      ElseIf Pt.Y > (Rect.Height - 30) Then
         Pt.Y = Rect.Height - 30
      End If
      If Pt.X < 0 Then
         Pt.X = 0
      ElseIf Pt.X > (Rect.Width - 30) Then
         Pt.X = Rect.Width - 30
      End If

      Frm.Location = Pt
      Frm.Size = Size
      If s(0) = "1" Then
         Frm.WindowState = FormWindowState.Maximized
      End If

   End Sub

   ''' <summary>
   ''' liefert die Daten von Size und Location einer Form in einem String
   ''' zum Abspeichern in den Einstellungen (Settings)
   ''' </summary>
   ''' <param name="Frm">die Form</param>
   ''' <returns></returns>
   ''' <remarks></remarks>
   Public Function FormGetSettings(ByVal Frm As Form) As String

      Dim s(4) As String
      If Frm.WindowState = FormWindowState.Normal Then
         s(0) = "0"
         s(1) = Frm.Left.ToString
         s(2) = Frm.Top.ToString
         s(3) = Frm.Width.ToString
         s(4) = Frm.Height.ToString
      Else
         If Frm.WindowState = FormWindowState.Maximized Then
            s(0) = "1"
         Else
            s(0) = "2"
         End If
         s(1) = Frm.RestoreBounds.X.ToString
         s(2) = Frm.RestoreBounds.Y.ToString
         s(3) = Frm.RestoreBounds.Width.ToString
         s(4) = Frm.RestoreBounds.Height.ToString
      End If
      Return String.Join(",", s)
   End Function

   ''' <summary>
   ''' stellt die Spaltenbreite in einem Datagridview wieder ein ber ein
   ''' per ....GetSettings erzeugten String
   ''' </summary>
   ''' <param name="DGV"></param>
   ''' <param name="Settings"></param>
   ''' <remarks></remarks>
   Public Sub DGVColumnWidthRestore(ByVal DGV As DataGridView, ByVal Settings As String)

      If String.IsNullOrEmpty(Settings) Then
         Exit Sub
      End If

      Dim s() As String = Settings.Split(","c)
      If (s.GetUpperBound(0) + 1) = DGV.Columns.Count Then
         For i As Integer = 0 To s.GetUpperBound(0)
            DGV.Columns(i).Width = Convert.ToInt32(s(i))
         Next
      End If
   End Sub

   ''' <summary>
   ''' liefert die Spaltenbreiten in einem Datagridview in einem String
   ''' </summary>
   ''' <param name="DGV"></param>
   ''' <returns></returns>
   ''' <remarks></remarks>
   Public Function DGVColumnWidthGetSettings(ByVal DGV As DataGridView) As String

      Using SR As New IO.StringWriter
         If DGV.Columns.Count > 0 Then
            For i As Integer = 0 To DGV.Columns.Count - 1
               SR.Write("," & DGV.Columns(i).Width.ToString)
            Next
            Return SR.ToString.Substring(1)
         End If
         Return Nothing
      End Using
   End Function

   ''' <summary>
   ''' liefert die (vom User eingestellte) Spaltenreihenfolge
   ''' (DisplayIndex) in einem DataGridView als String
   ''' </summary>
   ''' <param name="DGV">das DataGridView</param>
   ''' <returns></returns>
   ''' <remarks></remarks>
   Public Function DGVColumnOrderGetSettings(ByVal DGV As DataGridView) As String

      Using SW As New IO.StringWriter
         If DGV.Columns.Count > 0 Then
            For i As Integer = 0 To DGV.Columns.Count - 1
               SW.Write("," & DGV.Columns(i).DisplayIndex.ToString)
            Next
            Return SW.ToString.Substring(1)
         End If
      End Using
      Return Nothing
   End Function

   ''' <summary>
   ''' stellt die Spaltenreihenfolge in einem Datagridview wieder ein
   ''' </summary>
   ''' <param name="DGV">das DataGridView</param>
   ''' <param name="Settings">String aus den Settings</param>
   ''' <remarks></remarks>
   Public Sub DGVColumnsReOrder(ByVal DGV As DataGridView, ByVal Settings As String)

      If String.IsNullOrEmpty(Settings) Then
         Exit Sub
      End If

      Dim s() As String = Settings.Split(","c)
      If (s.GetUpperBound(0) + 1) = DGV.Columns.Count Then
         For i As Integer = 0 To DGV.Columns.Count - 1
            DGV.Columns(i).DisplayIndex = Convert.ToInt32(s(i))
         Next
      End If
   End Sub

   ''' <summary>
   ''' stellt die Spaltenbreite in einem Listview wieder ein ber ein
   ''' per ....GetSettings erzeugten String
   ''' </summary>
   ''' <param name="Lvw"></param>
   ''' <param name="settings"></param>
   ''' <remarks></remarks>
   Public Sub ListviewColumnWidthRestore(ByVal Lvw As ListView, ByVal Settings As String)

      If String.IsNullOrEmpty(Settings) Then
         Exit Sub
      End If

      Dim s() As String = Settings.Split(","c)
      If (s.GetUpperBound(0) + 1) = Lvw.Columns.Count Then
         For i As Integer = 0 To s.GetUpperBound(0)
            Lvw.Columns(i).Width = Integer.Parse(s(i))
         Next
      End If
   End Sub

   ''' <summary>
   ''' liefert die Spaltenbreiten in einem Datagridview in einem String
   ''' </summary>
   ''' <param name="Lvw"></param>
   ''' <returns></returns>
   ''' <remarks></remarks>
   Public Function ListviewColumnWidthGetSettings(ByVal Lvw As ListView) As String

      Using SW As New IO.StringWriter
         If Lvw.Columns.Count > 0 Then
            For i As Integer = 0 To Lvw.Columns.Count - 1
               SW.Write("," & Lvw.Columns(i).Width.ToString)
            Next
            Return SW.ToString.Substring(1)
         End If
         Return Nothing
      End Using
   End Function

   ''' <summary>
   ''' stellt in einem Listview ber Settings 
   ''' die Spaltenreihenfolge ein (DisplayIndex)
   ''' </summary>
   ''' <param name="Lvw">das Listview</param>
   ''' <param name="Settings">String aus Settings</param>
   ''' <remarks></remarks>
   Public Sub ListviewColumnsReOrder(ByVal Lvw As ListView, ByVal Settings As String)

      If String.IsNullOrEmpty(Settings) Then
         Exit Sub
      End If

      Dim s() As String = Settings.Split(","c)
      If (s.GetUpperBound(0) + 1) = Lvw.Columns.Count Then
         For i As Integer = 0 To Lvw.Columns.Count - 1
            Lvw.Columns(i).DisplayIndex = Convert.ToInt32(s(i))
         Next
      End If
   End Sub

   ''' <summary>
   ''' liefert die Spaltenreihenfolge in einem Listview (DisplayIndex)
   ''' fr die Speicherung in den Settings in einem String
   ''' </summary>
   ''' <param name="Lvw">das Listview</param>
   ''' <returns></returns>
   ''' <remarks></remarks>
   Public Function ListviewColumnOrderGetSettings(ByVal Lvw As ListView) As String

      Using SW As New IO.StringWriter
         For i As Integer = 0 To Lvw.Columns.Count - 1
            SW.Write("," & Lvw.Columns(i).DisplayIndex.ToString)
         Next
         If Lvw.Columns.Count > 0 Then
            Return SW.ToString.Substring(1)
         End If
         Return Nothing
      End Using
   End Function
End Class
